@@ -11,11 +11,11 @@ from typing import Any, List, Optional, Dict, Callable, Tuple
 
 from aiohttp import ClientOSError, ContentTypeError
 
-from wyzeapy.exceptions import UnknownApiError
-from wyzeapy.services.base_service import BaseService
-from wyzeapy.services.update_manager import DeviceUpdater
-from wyzeapy.types import Device, DeviceTypes, Event, PropertyIDs
-from wyzeapy.utils import return_event_for_device, create_pid_pair
+from ..exceptions import UnknownApiError
+from .base_service import BaseService
+from .update_manager import DeviceUpdater
+from ..types import Device, DeviceTypes, Event, PropertyIDs
+from ..utils import return_event_for_device, create_pid_pair
 
 _LOGGER = logging.getLogger(__name__)
 
@@ -27,6 +27,8 @@ class Camera(Device):
         self.last_event: Optional[Event] = None
         self.last_event_ts: int = int(time.time() * 1000)
         self.on: bool = True
+        self.siren: bool = False
+        self.floodlight: bool = False
 
 
 class CameraService(BaseService):
@@ -54,7 +56,11 @@ class CameraService(BaseService):
                 camera.available = value == "1"
             if property is PropertyIDs.ON:
                 camera.on = value == "1"
-
+            if property is PropertyIDs.CAMERA_SIREN:
+                camera.siren = value == "1"
+            if property is PropertyIDs.FLOOD_LIGHT:
+                camera.floodlight = value == "1"
+                
         return camera
 
     async def register_for_updates(self, camera: Camera, callback: Callable[[Camera], None]):
@@ -82,9 +88,6 @@ class CameraService(BaseService):
                         _LOGGER.error(f"A network error was detected: {e}")
                     except ContentTypeError as e:
                         _LOGGER.error(f"Server returned unexpected ContentType: {e}")
-                    except RuntimeError as e:
-                        if e == RuntimeError("Session is closed"):
-                            asyncio.run_coroutine_threadsafe(self._auth_lib.gen_session(), loop).result()
 
     async def get_cameras(self) -> List[Camera]:
         if self._devices is None:
@@ -100,6 +103,18 @@ class CameraService(BaseService):
     async def turn_off(self, camera: Camera):
         await self._run_action(camera, "power_off")
 
+    async def siren_on(self, camera: Camera):
+        await self._run_action(camera, "siren_on")
+
+    async def siren_off(self, camera: Camera):
+        await self._run_action(camera, "siren_off")
+
+    async def floodlight_on(self, camera: Camera):
+        await self._set_property(camera, PropertyIDs.FLOOD_LIGHT.value, "1")
+
+    async def floodlight_off(self, camera: Camera):
+        await self._set_property(camera, PropertyIDs.FLOOD_LIGHT.value, "2")
+        
     async def turn_on_notifications(self, camera: Camera):
         plist = [
             create_pid_pair(PropertyIDs.NOTIFICATION, "1")
@@ -113,7 +128,3 @@ class CameraService(BaseService):
         ]
 
         await self._set_property_list(camera, plist)
-
-    def register_updater(self, camera: Camera, interval):
-        dev_updater = DeviceUpdater(self, camera, interval)
-        BaseService._update_manager.add_updater(dev_updater)
