@@ -41,7 +41,7 @@ class DeviceTypes(Enum):
     UNKNOWN = "Unknown"
     SENSE_V2_GATEWAY = "S1Gateway"
     KEYPAD = "Keypad"
-
+    LIGHTSTRIP = "LightStrip"
 
 class Device:
     product_type: str
@@ -50,6 +50,7 @@ class Device:
     nickname: str
     device_params: Dict[str, Any]
     raw_dict: Dict[str, Any]
+    callback_function = None
 
     def __init__(self, dictionary: Dict[Any, Any]):
         self.available = False
@@ -94,9 +95,12 @@ class PropertyIDs(Enum):
     BRIGHTNESS = "P1501"  # From 0-100
     COLOR_TEMP = "P1502"  # In Kelvin
     COLOR = "P1507"  # As a hex string RrGgBb
+    COLOR_MODE = "P1508"  # 1 = Basic Color, 2 = White, 3 = Music Mode
     DOOR_OPEN = "P2001"  # 0 if the door is closed
     CONTACT_STATE = "P1301"
     MOTION_STATE = "P1302"
+    CAMERA_SIREN = "P1049"
+    FLOOD_LIGHT = "P1056"
 
 
 class ThermostatProps(Enum):
